@@ -1,5 +1,5 @@
 # set default values for the priors 
-fecr_setPrior <- function(muPrior, kappaPrior, deltaPrior, phiPrior){
+fecr_setPrior <- function(muPrior, kappaPrior, deltaPrior, phiPrior, deltakappaPrior){
   if(missing(muPrior)) muPrior = list(priorDist = "gamma",hyperpars=c(1,0.001))
   if(is.null(muPrior[["priorDist", exact = TRUE]])) muPrior$priorDist = "gamma"
   if(is.null(muPrior[["hyperpars", exact = TRUE]])) muPrior$hyperpars = c(1,0.001)
@@ -16,7 +16,11 @@ fecr_setPrior <- function(muPrior, kappaPrior, deltaPrior, phiPrior){
   if(is.null(phiPrior[["priorDist", exact = TRUE]])) phiPrior$priorDist = "beta"
   if(is.null(phiPrior[["hyperpars", exact = TRUE]])) phiPrior$hyperpars = c(1,1)
   
-  return(list(mu=muPrior,kappa=kappaPrior,delta=deltaPrior, phi = phiPrior))
+  if(missing(deltakappaPrior)) deltakappaPrior = list(priorDist = "normal",hyperpars=c(2,1))
+  if(is.null(deltakappaPrior[["priorDist", exact = TRUE]])) deltakappaPrior$priorDist = "normal"
+  if(is.null(deltakappaPrior[["hyperpars", exact = TRUE]])) deltakappaPrior$hyperpars = c(2,1)
+  
+  return(list(mu = muPrior, kappa = kappaPrior, delta = deltaPrior, phi = phiPrior, deltakappa = deltakappaPrior))
 }
 
 # Stan model code for paired model without zero inflation 
@@ -49,18 +53,16 @@ paired_stan <- function(priors){
            transformed parameters{
            real lambdaa[J];
            real lambdab[J];
-           real kappamu;
            for (i in 1:J){
            lambdab[i] = mub[i]/fpre[i];
            lambdaa[i] = delta*mub[i]/fpost[i];
            }
-           kappamu = kappa/mu;
            }
            model {
            mu ~ ',dist.mu,'(',a.mu,',',b.mu,');            // prior
            kappa ~ ',dist.kappa,'(',a.kappa,',',b.kappa,');
            delta ~ ',dist.delta,'(',a.delta,',',b.delta,');
-           mub ~ gamma(kappa,kappamu);           // likelihoods
+           mub ~ gamma(kappa, kappa/mu);           // likelihoods
            ystarbraw ~ poisson(lambdab);
            ystararaw ~ poisson(lambdaa);
            }')
@@ -113,7 +115,8 @@ unpaired_stan <- function(priors){
            mu ~ ',dist.mu,'(',a.mu,',',b.mu,'); 
            kappa ~ ',dist.kappa,'(',a.kappa,',',b.kappa,');
            delta ~ ',dist.delta,'(',a.delta,',',b.delta,');
-           target += gamma_lpdf(mub | kappa,kappamu)+gamma_lpdf(mua | kappa,kappamu);             // likelihoods
+           mub ~ gamma(kappa, kappa/mu); 
+           mua ~ gamma(kappa, kappa/mu);       
            ystarbraw ~ poisson(lambdab);
            ystararaw ~ poisson(lambdaa);
            }')
@@ -157,14 +160,12 @@ ZI_unpaired_stan <- function(priors){
         transformed parameters{
           real lambdaa[Ja];
           real lambdab[Jb];
-          real kappamu;
           for (i in 1:Jb){
             lambdab[i] = mub[i]/fpre[i];
           }
           for (i in 1:Ja){
             lambdaa[i] = delta*mua[i]/fpost[i];
           }
-          kappamu = kappa/mu;
         }
         model {
           // prior
@@ -173,8 +174,8 @@ ZI_unpaired_stan <- function(priors){
           delta ~ ',dist.delta,'(',a.delta,',',b.delta,');
           phi ~ ',dist.phi,'(',a.phi,',',b.phi,');
           // likelihoods
-          mub ~ gamma(kappa,kappamu); 
-          mua ~ gamma(kappa,kappamu); 
+          mub ~ gamma(kappa, kappa/mu); 
+          mua ~ gamma(kappa, kappa/mu); 
           for (n in 1:Jb) {
              if (ystarbraw[n] == 0)
                 target += log_sum_exp(bernoulli_lpmf(1 | phi), bernoulli_lpmf(0 | phi)+poisson_lpmf(ystarbraw[n] | lambdab[n]));
@@ -226,19 +227,17 @@ ZI_paired_stan <- function(priors){
         transformed parameters{
           real lambdaa[J];
           real lambdab[J];
-          real kappamu;
           for (i in 1:J){
             lambdab[i] = mub[i]/fpre[i];
             lambdaa[i] = delta*mub[i]/fpost[i];
           }
-          kappamu = kappa/mu;
         }
         model {
           mu ~ ',dist.mu,'(',a.mu,',',b.mu,');           // prior
           kappa ~ ',dist.kappa,'(',a.kappa,',',b.kappa,');
           delta ~ ',dist.delta,'(',a.delta,',',b.delta,');
           phi ~ ',dist.phi,'(',a.phi,',',b.phi,');
-          mub ~ gamma(kappa,kappamu);           // likelihoods
+          mub ~ gamma(kappa, kappa/mu);           // likelihoods
           for (n in 1:J) {
           if (ystarbraw[n] == 0)
             target += log_sum_exp(bernoulli_lpmf(1 | phi), bernoulli_lpmf(0 | phi)+poisson_lpmf(ystarbraw[n] | lambdab[n]));
@@ -254,3 +253,93 @@ ZI_paired_stan <- function(priors){
         }
 ')
 }
+
+
+
+# Stan model code for paired model without zero inflation allowing for individual efficacy
+indeff_stan <- function(priors){
+  #hyperparameters for pre-treatment mean mu
+  a.mu <- priors$mu$hyperpars[1]
+  b.mu <- priors$mu$hyperpars[2]
+  dist.mu <- priors$mu$priorDist
+  #hyperparameters  for overdispersion parameter kappa
+  a.kappa <- priors$kappa$hyperpars[1]
+  b.kappa <- priors$kappa$hyperpars[2]
+  dist.kappa <- priors$kappa$priorDist
+  #hyperparameters  for change in mean delta
+  a.delta <- priors$delta$hyperpars[1]
+  b.delta <- priors$delta$hyperpars[2]
+  dist.delta <- priors$delta$priorDist
+  #hyperparameters for shape of delta
+  a.deltakappa <- priors$deltakappa$hyperpars[1]
+  b.deltakappa <- priors$deltakappa$hyperpars[2]
+  dist.deltakappa <- priors$deltakappa$priorDist
+  
+  paste0('data {
+           int J; // number of animals
+           int ystararaw[J]; // after treatment McMaster count
+           int ystarbraw[J]; // before treatment McMaster count
+           int fpre[J];
+           int fpost[J];
+           }
+           parameters {
+           real<lower=0> kappa;
+           real<lower=0> mu;
+           real<lower=0> delta[J];
+           real<lower=0> delta_shape;
+           real<lower=0> delta_mu;
+           real<lower=0> mub[J];
+           }
+           transformed parameters{
+           real lambdaa[J];
+           real lambdab[J];
+           for (i in 1:J){
+           lambdab[i] = mub[i]/fpre[i];
+           lambdaa[i] = delta[i]*mub[i]/fpost[i];
+           }
+           }
+           model {
+           mu ~ ',dist.mu,'(',a.mu,',',b.mu,');            // prior
+           delta ~ gamma(delta_shape, delta_shape/delta_mu); // shape, rate
+           delta_shape ~ ',dist.deltakappa,'(',a.deltakappa,',',b.deltakappa,');
+           delta_mu ~ ',dist.delta,'(',a.delta,',',b.delta,');
+           mub ~ gamma(kappa, kappa/mu);           // likelihoods
+           ystarbraw ~ poisson(lambdab);
+           ystararaw ~ poisson(lambdaa);
+           }')
+}
+
+
+######################## stan models for simple model #############
+# Stan model code for paired model without zero inflation 
+simple_paired_stan <- function(priors){
+  #hyperparameters  for change in mean delta
+  a.delta <- priors$delta$hyperpars[1]
+  b.delta <- priors$delta$hyperpars[2]
+  dist.delta <- priors$delta$priorDist
+  paste0('data {
+         int J; // number of animals
+         int ystararaw[J]; // after treatment McMaster count
+         int ystarbraw[J]; // before treatment McMaster count
+         int fpre[J];
+         int fpost[J];
+}
+parameters {
+real<lower=0> delta;
+real<lower=0> mu;
+}
+transformed parameters{
+real lambdaa[J];
+real lambdab[J];
+for (i in 1:J){
+lambdab[i] = mu/fpre[i];
+lambdaa[i] = delta*mu/fpost[i];
+}
+}
+model {
+delta ~ ',dist.delta,'(',a.delta,',',b.delta,');   // prior
+mu ~ gamma(1, 0.001);  
+ystarbraw ~ poisson(lambdab);
+ystararaw ~ poisson(lambdaa);
+}')
+}
\ No newline at end of file
